@@ -17,7 +17,9 @@
 #' 
 ###
 kappaSet = function(set){
-  if(length(set[(set > 0 && set < 1) | set > 1 | set < 0]) != 0) stop("Each set must only consist of zeros and ones.")
+  if(length(set[(set > 0 && set < 1) | set > 1 | set < 0]) != 0) {
+    stop("Each set must only consist of zeros and ones.")
+  }
   
   return(calcKappa(set,isSet = TRUE,kappaThreshold = NULL));
 }
